@@ -2,8 +2,7 @@ from django.core.management import call_command
 from django.test import TestCase
 from entity_event.models import Medium, Source
 
-from entity_emailer import get_medium, get_admin_source, get_admin_template
-from entity_emailer.models import EmailTemplate
+from entity_emailer.utils import get_medium, get_admin_source
 
 
 class AddEmailMediumCommandTest(TestCase):
@@ -30,14 +29,11 @@ class EntityEmailerAdminSetupTest(TestCase):
         call_command('entity_emailer_admin_setup')
         call_command('entity_emailer_admin_setup')
         self.assertEqual(Source.objects.count(), 1)
-        self.assertEqual(EmailTemplate.objects.count(), 1)
 
     def test_defaults(self):
         call_command('entity_emailer_admin_setup')
         source = get_admin_source()
-        template = get_admin_template()
         self.assertEqual(source.name, 'admin')
-        self.assertEqual(template.template_name, 'html_safe')
 
     def test_custom_source(self):
         custom_source_name = 'test-email'
@@ -45,10 +41,3 @@ class EntityEmailerAdminSetupTest(TestCase):
             call_command('entity_emailer_admin_setup')
             source = get_admin_source()
         self.assertEqual(source.name, custom_source_name)
-
-    def test_custom_template(self):
-        custom_template_name = 'test-html'
-        with self.settings(ENTITY_EMAILER_ADMIN_TEMPLATE_NAME=custom_template_name):
-            call_command('entity_emailer_admin_setup')
-            template = get_admin_template()
-        self.assertEqual(template.template_name, custom_template_name)
